==> gs2-cdk-1.0.62.tar.gz: gs2-cdk-1.0.62/src/gs2_cdk/experience/stamp_sheet/AddExperienceByUserId.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *

from ...core.model import AcquireAction, ConsumeAction


class AddExperienceByUserId(AcquireAction):

    def __init__(
        self,
        namespace_name: str,
        experience_name: str,
        property_id: str,
        experience_value: Optional[int] = None,
        truncate_experience_when_rank_up: Optional[bool] = None,
        user_id: Optional[str] = "#{userId}",
    ):
        properties: Dict[str, Any] = {}

        properties["namespaceName"] = namespace_name
        properties["experienceName"] = experience_name
        properties["propertyId"] = property_id
        properties["experienceValue"] = experience_value
        properties["truncateExperienceWhenRankUp"] = truncate_experience_when_rank_up
        properties["userId"] = user_id

        super().__init__(
            "Gs2Experience:AddExperienceByUserId",
            properties,
        )

==> gs2-cdk-1.0.109.tar.gz: gs2-cdk-1.0.109/src/gs2_cdk/experience/stamp_sheet/AddExperienceByUserId.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *

from ...core.model import AcquireAction, ConsumeAction, VerifyAction


class AddExperienceByUserId(AcquireAction):

    def __init__(
        self,
        namespace_name: str,
        experience_name: str,
        property_id: str,
        experience_value: Optional[int] = None,
        truncate_experience_when_rank_up: Optional[bool] = None,
        user_id: Optional[str] = "#{userId}",
    ):
        properties: Dict[str, Any] = {}

        properties["namespaceName"] = namespace_name
        properties["experienceName"] = experience_name
        properties["propertyId"] = property_id
        properties["experienceValue"] = experience_value
        properties["truncateExperienceWhenRankUp"] = truncate_experience_when_rank_up
        properties["userId"] = user_id

        super().__init__(
            "Gs2Experience:AddExperienceByUserId",
            properties,
        )
